@@ -1,21 +1,21 @@
 # -*- coding: utf-8 -*-
-##
-## This file is part of intbitset.
-## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2013, 2014 CERN.
-##
-## intbitset is free software; you can redistribute it and/or
-## modify it under the terms of the GNU General Public License as
-## published by the Free Software Foundation; either version 2 of the
-## License, or (at your option) any later version.
-##
-## intbitset is distributed in the hope that it will be useful, but
-## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with intbitset; if not, write to the Free Software Foundation, Inc.,
-## 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+#
+# This file is part of intbitset.
+# Copyright (C) 2007, 2008, 2009, 2010, 2011, 2013, 2014, 2015 CERN.
+#
+# intbitset is free software; you can redistribute it and/or
+# modify it under the terms of the GNU General Public License as
+# published by the Free Software Foundation; either version 2 of the
+# License, or (at your option) any later version.
+#
+# intbitset is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with intbitset; if not, write to the Free Software Foundation, Inc.,
+# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
 """Unit tests for the intbitset data structure."""
 
@@ -179,6 +179,7 @@ class IntbitsetTest(unittest.TestCase):
         for intbitset_fnc, set_fnc, dummy, dummy in self.fncs_list:
             self.assertRaises(TypeError, intbitset_fnc, (self.intbitset([1,2,3]), set([1,2,3])))
             self.assertRaises(TypeError, set_fnc, (set([1,2,3]), self.intbitset([1,2,3])))
+            self.assertRaises(TypeError, intbitset_fnc, (None, self.intbitset([1,2,3])))
 
     def test_set_intersection(self):
         """intbitset - set intersection, normal set"""
@@ -341,9 +342,9 @@ class IntbitsetTest(unittest.TestCase):
     def test_marshalling(self):
         """intbitset - marshalling"""
         for set1 in self.sets + [[]]:
-            self.assertEqual(self.intbitset(set1), self.intbitset().fastload((self.intbitset(set1).fastdump())))
+            self.assertEqual(self.intbitset(set1), self.intbitset(self.intbitset(set1).fastdump()))
         for set1 in self.sets + [[]]:
-            self.assertEqual(self.intbitset(set1, trailing_bits=True), self.intbitset().fastload(self.intbitset(set1, trailing_bits=True).fastdump()))
+            self.assertEqual(self.intbitset(set1, trailing_bits=True), self.intbitset(self.intbitset(set1, trailing_bits=True).fastdump()))
 
     def test_pickling(self):
         """intbitset - pickling"""
